documentFactory.SyndicationDocumentStream

|  | ## Cheshire3 Object Model: Class SyndicationDocumentStream

Module documentFactory :: Class SyndicationDocumentStream

## Class SyndicationDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
    MultipleDocumentStream --+
                             |
            HttpDocumentStream --+
                                 |
                                SyndicationDocumentStream

Instance Methods

find_documents(self, session, cache=0)
open_stream(self, stream)
toXml(self, i)
Inherited from `HttpDocumentStream`: `__init__` Inherited from `HttpDocumentStream` (private): `_fetchName`, `_fetchStream`, `_processFile` Inherited from `MultipleDocumentStream` (private): `_processFiles` Inherited from `BaseDocumentStream`: `fetch_document`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### find_documents(self, session, cache=0) | source code
Overrides: HttpDocumentStream.find_documents

### open_stream(self, stream) | source code
Overrides: BaseDocumentStream.open_stream

### toXml(self, i) | source code